@@ -3,11 +3,24 @@ import re
 import urllib.parse
 import difflib
 
-__version__ = '0.0.4'
+__version__ = '0.0.6'
 
 _hdr_pat = re.compile("^@@ -(\d+),?(\d+)? \+(\d+),?(\d+)? @@$")
 _no_eol = "\ No newline at end of file"
 
+inline_patterns = [
+    '(?:^|[ \t])+\/\/(.*)',
+    '(?:^|[ \t])+#(.*)',
+    '(?:^|[ \t])+;(.*)'
+]
+
+block_patterns = [
+    '(?:^|[ \t])+\/\*(((?!\/\*).)|\n|\r)*\*\/',
+    '(?:^|[ \t])+"""(((?!""").)|\n|\r)*"""',
+    '(?:^|[ \t])+\'\'\'(((?!\'\'\').)|\n|\r)*\'\'\'',
+    '(?:^|[ \t])+<!--(((?!<!--).)|\n|\r)*-->'
+]
+
 class JSONCDict(dict):
     def __init__(self, *args, **kwargs):
         """
@@ -206,11 +219,15 @@ def loads(text):
     """
     Initialize a JSONCDict from a string
     """
-    inline_pattern = re.compile(r'(?:^|[ \t])+\/\/(.*)', re.MULTILINE)
-    multiline_pattern = re.compile(r'(?:^|[ \t])+\/\*(((?!\/\*).)|\n|\r)*\*\/')
+    # inline_pattern = re.compile(r'(?:^|[ \t])+\/\/(.*)', re.MULTILINE)
+    # multiline_pattern = re.compile(r'(?:^|[ \t])+\/\*(((?!\/\*).)|\n|\r)*\*\/')
+
+    no_comments = text
+    for inline_pattern in inline_patterns:
+        no_comments = re.sub(inline_pattern, '', no_comments)
+    for block_pattern in block_patterns:
+        no_comments = re.sub(block_pattern, '', no_comments)
 
-    no_comments = re.sub(inline_pattern, '', text)
-    no_comments = re.sub(multiline_pattern, '', no_comments)
     # get the "without comments" version of the data
     json_obj = json.loads(no_comments)
 
@@ -221,15 +238,29 @@ def loads(text):
 
     return dict_obj
 
-def dumps(data):
+def dumps(data, indent=4, comments=True):
     """
     Write the JSONCDict to a string
     """
-    return data.with_comments
+    if indent <=0 :
+        err = ValueError('Indent value must be greater or equal to 1')
+        raise err
+    if comments:
+        lines = data.with_comments.split('\n')
+    else:
+        lines = data.without_comments.split('\n')
+    for i in range(0, len(lines)):
+        line_strip = lines[i].lstrip()
+        space_count = len(lines[i]) - len(line_strip)
+        indent_level = space_count / 4
+        space_count = int(indent_level * indent)
+        lines[i] = ' ' * space_count + line_strip
 
-def dump(data, stream):
+    return '\n'.join(lines)
+
+def dump(data, stream, indent=4, comments=True):
     """
     Write the JSONCDict to a file
     """
-    text = dumps(data, indent=4)
+    text = dumps(data, indent=indent, comments=comments)
     stream.write(text)
\ No newline at end of file
